@@ -10,7 +10,7 @@
   s3_register("adbcdrivermanager::adbc_connection_init", "duckdb_database_adbc")
   s3_register("adbcdrivermanager::adbc_statement_init", "duckdb_connection_adbc")
 
-  if (!requireNamespace("rlang")) {
+  if (!requireNamespace("rlang", quietly = TRUE)) {
     rethrow_restore()
   }
 
