@@ -766,25 +766,29 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 	auto y_data = FlatVector::GetData<RHS_TYPE>(ListVector::GetEntry(y));
 	auto y_mask = FlatVector::Validity(ListVector::GetEntry(y));
 
-	bool na_in_y = [&](){
-		if (!y_mask.AllValid()) {
-			idx_t y_base_idx = 0;
-			auto y_entry_count = ValidityMask::EntryCount(y_size);
-			for (idx_t y_entry_idx = 0; y_entry_idx < y_entry_count; y_entry_idx++) {
-				auto y_validity_entry = y_mask.GetValidityEntry(y_entry_idx);
-				idx_t y_next = MinValue<idx_t>(y_base_idx + ValidityMask::BITS_PER_VALUE, y_size);
+	bool na_in_y = [&]() {
+		if (y_mask.AllValid()) {
+			return false;
+		}
 
-				if (!ValidityMask::AllValid(y_validity_entry)) {
-					if (ValidityMask::NoneValid(y_validity_entry)) {
-						return true;
-					} else {
-						idx_t y_start = y_base_idx;
-						for (; y_base_idx < y_next; y_base_idx++) {
-							if (!ValidityMask::RowIsValid(y_validity_entry, y_base_idx - y_start)) {
-								return true;
-							}
-						}
-					}
+		idx_t y_base_idx = 0;
+		auto y_entry_count = ValidityMask::EntryCount(y_size);
+		for (idx_t y_entry_idx = 0; y_entry_idx < y_entry_count; y_entry_idx++) {
+			auto y_validity_entry = y_mask.GetValidityEntry(y_entry_idx);
+			idx_t y_next = MinValue<idx_t>(y_base_idx + ValidityMask::BITS_PER_VALUE, y_size);
+
+			if (ValidityMask::AllValid(y_validity_entry)) {
+				continue;
+			}
+
+			if (ValidityMask::NoneValid(y_validity_entry)) {
+				return true;
+			}
+
+			idx_t y_start = y_base_idx;
+			for (; y_base_idx < y_next; y_base_idx++) {
+				if (!ValidityMask::RowIsValid(y_validity_entry, y_base_idx - y_start)) {
+					return true;
 				}
 			}
 		}
@@ -792,11 +796,10 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 		return false;
 	}();
 
-
 	auto is_in_y = [&](LHS_TYPE left) {
 		// special case when there are no NAs in y
 		if (!na_in_y) {
-			for (int i = 0; i < y_size; i++) {
+			for (idx_t i = 0; i < y_size; i++) {
 				if (try_equal(left, y_data[i])) {
 					return true;
 				}
@@ -819,7 +822,8 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 				}
 			} else if (ValidityMask::NoneValid(y_validity_entry)) {
 				// nothing to do, because inside is_in_y() we know left is valid
-				for (; y_base_idx < y_next; y_base_idx++) {}
+				for (; y_base_idx < y_next; y_base_idx++) {
+				}
 			} else {
 				idx_t y_start = y_base_idx;
 
@@ -831,12 +835,11 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 					}
 				}
 			}
-
 		}
 		return false;
 	};
 
-	auto in_loop = [&](idx_t count, LHS_TYPE* x_data, bool* result_data, ValidityMask mask) {
+	auto in_loop = [&](idx_t count, const LHS_TYPE *x_data, bool *result_data, const ValidityMask &mask) {
 		idx_t base_idx = 0;
 		auto entry_count = ValidityMask::EntryCount(count);
 		for (idx_t entry_idx = 0; entry_idx < entry_count; entry_idx++) {
@@ -889,13 +892,13 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 			break;
 		}
 
-		default : {
+		default: {
 			UnifiedVectorFormat vdata;
 			x.ToUnifiedFormat(count, vdata);
 			result.SetVectorType(VectorType::FLAT_VECTOR);
 			in_loop(
 				count,
-				FlatVector::GetData<LHS_TYPE>(x),
+				UnifiedVectorFormat::GetData<LHS_TYPE>(vdata),
 				FlatVector::GetData<bool>(result),
 				vdata.validity
 			);
@@ -903,7 +906,6 @@ void InExecute(DataChunk &args, ExpressionState &state, Vector &result) {
 			break;
 		}
 	}
-
 }
 
 #define IN_VARIANT(__LHS__, __RHS__) ScalarFunction(                                      \
